<?php

/**
 * Dynamic Inline Styles
 * @package Serifi
 * @since 1.0.0
 */

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}

// Dynamic CSS
if (!function_exists('serifi_inline_css')) :
	function serifi_inline_css()
	{

		/* Typography*/
		$site_title_font_size = get_theme_mod('site_title_font_size', '1');
		$site_title_font_size_basic = get_theme_mod('site_title_font_size_basic', '2');
		$serifi_font_size  = get_theme_mod('serifi_font_size', 16);

		/* Base Colours */
		$serifi_content_line_colour = get_theme_mod('serifi_content_line_colour', '#f1f1f1');

		echo '<style type="text/css" media="all">';
?>

		:root {
		--serifi-splash-overlay-opacity: <?php echo esc_attr(get_theme_mod('serifi_splash_overlay_opacity', 0.2)); ?>;

		--serifi-tagline-colour: <?php echo esc_attr(get_theme_mod('serifi_tagline_colour', '#777')); ?>;
		--serifi-colour-sitetitle: <?php echo esc_attr(get_theme_mod('serifi_header_title_colour', '#333')); ?>;

		<?php if (!esc_attr(get_theme_mod('serifi_custom_accent_colours', false))) {
			serifi_inline_colour_presets();
		} else { ?>
			--serifi-colour-primary: <?php echo esc_attr(get_theme_mod('serifi_custom_primary_colour', '#818f9e')); ?>;
			--serifi-colour-secondary: <?php echo esc_attr(get_theme_mod('serifi_custom_secondary_colour', '#a6924a')); ?>;
			--serifi-colour-tertiary: <?php echo esc_attr(get_theme_mod('serifi_custom_tertiary_colour', '#2d283f')); ?>;
			--serifi-content-bg-colour: <?php echo esc_attr(get_theme_mod('serifi_content_bg_colour', '#fff')); ?>;
		<?php }	?>
		}

		<?php if (!esc_attr(get_theme_mod('serifi_custom_accent_colours', false))) { ?>
				body.custom-background {
				background-color: var(--serifi-colour-body-bg);
				}

				@media (min-width: 992px) {
				.primary-navigation .nav-menu li a:focus,
				.primary-navigation .nav-menu li a:hover {
				background: var( --serifi-colour-primary );
				color: var(--serifi-colour-white);
				}

				.primary-navigation .nav-menu .sub-menu,
				.primary-navigation .nav-menu .children {
				background: var( --serifi-content-bg-colour );
				border-color: var( --serifi-colour-primary );
				}
				#colophon {
				background: var(--serifi-colour-tertiary);
				}			
						
			}
		<?php }	?>
		
		html {
		font-size: <?php echo absint($serifi_font_size); ?>px;
		font-size: calc(<?php echo absint($serifi_font_size); ?>px + 0.0188vw);
		}


		.splash-hero::before {
			opacity: var(--serifi-splash-overlay-opacity);
		}

		#showcase-image {
			min-height: <?php echo esc_attr(  get_theme_mod( 'serifi_showcase_image_height', 450 )); ?>px;
		}
		
		#site-title:not(#splash-site-branding #site-title) {
		font-size: calc(1rem + <?php echo esc_attr($site_title_font_size); ?>vw);
		}

		.header-header3 #site-title {
		font-size: calc(2rem + <?php echo esc_attr($site_title_font_size); ?>vw);
		}

		.template-showcase-full.page.header-image #site-title a,
		.template-showcase-full.page.header-image #site-title a:visited,
		#site-title a,
		#site-title a:visited {
		color: var(--serifi-colour-sitetitle);
		}
		#site-description {
		color: var(--serifi-tagline-colour);
		}
		
		a.button,
		a.button:visited,
		.button a,
		.button a:visited,
		button,
		input[type="button"],
		input[type="reset"],
		input[type="submit"],	
		.wp-block-button__link,
		.wp-block-button__link:visited,
		.wp-block-button__link:active,


		button:focus,
		.button a:focus,
		input[type="button"]:focus,
		input[type="reset"]:focus,
		input[type="submit"]:focus,
		button:hover,
		.button a:hover,
		input[type="button"]:hover,
		input[type="reset"]:hover,
		input[type="submit"]:hover,
		a.button:focus,
		a.button:hover,
		.button a:focus,
		.button a:hover,		
		.wp-block-button__link:focus, 
		.wp-block-button__link:hover {
			background: var( --serifi-colour-primary );
			color: #fff;
		}

		a.button:focus,
		a.button:hover,
		.button a:focus,
		.button a:hover,		
		.wp-block-button__link:focus, 
		.wp-block-button__link:hover {
			opacity: 0.8;
		}

				.has-primary-background-color,
				.wp-block-button__link.has-primary-background-color				{
					background: var( --serifi-colour-primary );
				}
				.has-secondary-background-color,
				.wp-block-button__link.has-secondary-background-color {
					background: var( --serifi-colour-secondary );
				}
				.has-tertiary-background-color,
				.wp-block-button__link.has-tertiary-background-color {
					background: var(--serifi-colour-tertiary);
				}

				.has-primary-color,
				.has-primary .has-inline-color,
				.wp-block-button__link.has-primary-color {
					color: var( --serifi-colour-primary );
				}
				.has-secondary-color,
				.has-secondary-color .has-inline-color,
				.wp-block-button__link.has-secondary-color {
					color: var( --serifi-colour-secondary );
				}
				.has-tertiary-color,
				.has-tertiary .has-inline-color,
				.wp-block-button__link.has-tertiary-color {
					color: var(--serifi-colour-tertiary);
				}
		
		<?php if ( is_active_sidebar( 'banner'  )) { ?>
			#site-header {
				border: none;
			}
		<?php } ?>
		
		<?php if (esc_attr(get_theme_mod('serifi_greyscale_images', 0))) {	 ?>
			img, 
			#hero-image	{
			-webkit-filter: grayscale(100%);
			filter: grayscale(100%);
			}
		<?php } ?>

		<?php if (esc_attr(get_theme_mod('serifi_hide_banner_captions', 0))) {	 ?>
			#banner-sidebar .wp-caption-text {
			display: none;
			}
		<?php } ?>

<?php echo '</style>';
	}
endif;
add_action('wp_head', 'serifi_inline_css', 99);
