<?php
/**
 * Custom template tags for this theme
 * @package Serifi
 * @since 1.0.2
 */
 
 if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}


/* POST DATES
   ==================================================== */
if ( ! function_exists( 'serifi_posted_on' ) ) :
	// Returns the post date
	function serifi_posted_on() {

		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
			);
		
		echo '<li class="publish-date"><i class="bi bi-calendar3"></i><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a></li>';
	}
endif;

/* UPDATED POST DATE
   ==================================================== */
if ( ! function_exists( 'serifi_updated' ) ) :
	function serifi_updated() {
		printf( 	
		'<li class="posted-update">' .	esc_html__( 'Updated <span>%s</span>', 'serifi' ) .'</li>', get_the_modified_date() );
	}
endif;


/* META AUTHOR INFO
   ==================================================== */
if ( ! function_exists( 'serifi_posted_by' ) ) :
	function serifi_posted_by() {
		printf(
			'<li class="byline"><i class="bi bi-person-square"></i><span class="author vcard"><a class="url fn n" href="%1$s">%2$s</a></span></li>',
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			esc_html( get_the_author() )
		);
	}
endif;

/* META COMMENT COUNT & LINK
   ==================================================== */
if ( ! function_exists( 'serifi_comment_link' ) ) :
	function serifi_comment_link() {
		if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<li class="comments-link"><i class="bi bi-chat-right-text"></i>';
			/* translators: %s: Name of current post. Only visible to screen readers. */
			comments_popup_link( sprintf( __( 'Make a comment<span class="screen-reader-text"> on %s</span>', 'serifi' ), get_the_title() ) );

			echo '</li>';
		}
	}
endif;

/* META POST FORMAT
   ==================================================== */
if ( ! function_exists( 'serifi_post_format' ) ) :
	// Returns the post date
	function serifi_post_format() {
		
		$format = get_post_format();
		if ( current_theme_supports( 'post-formats', $format ) ) {		
			printf( '<li class="post-format"><i class="bi bi-journals"></i><a href="%1$s">%2$s</a></li>',
				
				esc_url( get_post_format_link( $format ) ),
				esc_html(get_post_format_string( $format ))				
			);
		}
	}
endif;

/* META EDIT LINK
   ==================================================== */
if ( ! function_exists( 'serifi_edit_link' ) ) :
	function serifi_edit_link() {
		edit_post_link(
			sprintf(
				/* translators: %s: Name of current post */
				__( 'Edit Post<span class="screen-reader-text">%s</span>', 'serifi' ),
				get_the_title()
			),
			'<li class="edit-link"><i class="bi bi-pencil-square"></i>',
			'</li>'
		);
	}
endif;

/* DISPLAY A SINGLE POST CATEGORY
   ==================================================== */
if ( ! function_exists( 'serifi_first_category' ) ) :
	function serifi_first_category() {	
		$category = get_the_category();
		$first_category = $category[0];
		echo sprintf( 		
		'<div class="cat-links"><a href="%s">%s</a></div>', get_category_link( $first_category ), $first_category->name ); // phpcs:ignore WordPress.Security.EscapeOutput
	}
endif;


/* DISPLAY ALL POST CATEGORIES
   ==================================================== */
if ( ! function_exists( 'serifi_post_categories' ) ) :
	function serifi_post_categories() {
			  $categories_list = get_the_category_list( esc_attr_x( ', ', 'Used between list items, there is a space after the comma.', 'serifi' ) );
			  if ( $categories_list ) {
				echo sprintf( '<div class="post-cat-links"><i class="bi bi-collection"></i>' . esc_html__( 'Categories:  ', 'serifi' ) . ' %s</div>', $categories_list ); 
			  }
	}
endif;

/* DISPLAY POST TAGS
   ==================================================== */
if ( ! function_exists( 'serifi_post_tags' ) ) :
	function serifi_post_tags() {	 
				$tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'serifi' ) );
			if ( $tags_list ) {
				/* translators: 1: list of tags. */
				printf( '<div class="post-tag-links"><i class="bi bi-tags"></i>' . esc_html__( 'Tags: %1$s', 'serifi' ) . '</div>', $tags_list ); 
			}	
	}
endif;

/* DISPLAY FEATURED or CATEGORY LABEL
   ==================================================== */
if ( ! function_exists( 'serifi_featured_cat_labels' ) ) {
function serifi_featured_cat_labels() {
		$serifi_featured_label_text = get_theme_mod( 'serifi_featured_label_text', esc_html__('Featured', 'serifi' ) );
		
		if( is_sticky() && is_home() && ! is_paged() && !esc_attr(get_theme_mod( 'serifi_hide_featured_labels', 0 )) ) { 
		echo '<span class="featured-label">' . wp_kses_post( $serifi_featured_label_text ) . '</span>';
		
		}  else {
		
			serifi_first_category();

		}
	}
}


/* DISPLAY THE SUMMARY POST META INFO
   ==================================================== */
if ( ! function_exists( 'serifi_entry_meta' ) ) :

	function serifi_entry_meta() {

		echo '<ul class="post-details">' ;	
			
				serifi_post_format();			
				serifi_posted_on();	
				serifi_posted_by();	
				serifi_comment_link();	
				if (!esc_attr(get_theme_mod( 'serifi_hide_edit', 0 ))) {
					serifi_edit_link();
				}
		
		echo '</ul>';
	}
endif;

/* DISPLAY MINI SUMMARY POST META INFO
   ==================================================== */
if ( ! function_exists( 'serifi_entry_mini_meta' ) ) :

	function serifi_entry_mini_meta() {

		echo '<ul class="post-details">' ;	
				serifi_posted_on();
		echo '</ul>';
	}
endif;


/* BIO INFO
   ==================================================== */
if ( ! function_exists( 'serifi_bio_info' ) ) :
  function serifi_bio_info() {

$serifi_view_posts_by_text = get_theme_mod( 'serifi_view_posts_by_text', esc_html__('View Posts By', 'serifi' ) );

echo '<div class="author-info">';
    printf( '<div class="author-avatar">%s</div>', get_avatar( get_the_author_meta( 'user_email' ), 150 ) ); 

echo '<div class="author-description">';
  printf( '<h3 class="author-heading section-heading">%s</h3>', sprintf( esc_html__( 'Published by %s', 'serifi' ), get_the_author() ) ); 
  echo '<p class="author-bio">';
      the_author_meta( 'description' ); 
   echo '</p><a class="author-link" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '" rel="author">';
echo '<span class="author-link-label">' . wp_kses_post( $serifi_view_posts_by_text ), '</span>&nbsp;', get_the_author();
    echo '</a></div></div>';

  }
endif;


/* POST FOOTER
   ==================================================== */
if ( ! function_exists( 'serifi_entry_footer' ) ) :
  function serifi_entry_footer() {
  
		echo '<footer class="entry-footer">' ;
		
		// Post categories
		if (!esc_attr(get_theme_mod( 'serifi_hide_post_category_tags', 0 ))) {
			serifi_post_categories();
		}
		// Post tags
		if (!esc_attr(get_theme_mod( 'serifi_hide_post_tags', 0 ))) {
			serifi_post_tags();
		}
		
		echo '</footer>';

  }
endif;

/* DISPLAY OPTIONAL POST THUMBNAIL
	Wraps the post thumbnail in an anchor element on index views, 
	or a div element when on single views.
   ==================================================== */
	if ( ! function_exists( 'serifi_post_thumbnail' ) ) {
		function serifi_post_thumbnail() {
			if ( ! serifi_can_show_post_thumbnail() ) {
				return;
			}
			?>

			<?php 
			if ( is_single() ): ?>
		
				<figure class="post-thumbnail">
					<?php the_post_thumbnail( 'post-thumbnail', array(						
					'alt' => the_title_attribute( array( 
					'echo' => false )),
					) );	?>
				</figure>

			<?php elseif (is_page() ) : ?>
			
			<div class="row">
				<div class="col">
							<figure class="post-thumbnail">
						<?php the_post_thumbnail( 'post-thumbnail', array(						
						'alt' => the_title_attribute( array( 
						'echo' => false )),
						) );	?>
					</figure>
				</div>
			</div>
			
			<?php else : ?>

				<figure class="post-thumbnail">
					<a class="post-thumbnail-link" href="<?php esc_url( the_permalink() ); ?>" aria-hidden="true">
						<?php the_post_thumbnail( 'post-thumbnail', array(						
						'alt' => the_title_attribute( array( 
						'echo' => false )),
						) );	?>
					</a>
				</figure>

			<?php endif; ?>
			
		
			<?php
		}
	}
	
	
/* BLOG  NAVIGATION
	Navigation for the blog
   ==================================================== */
if ( ! function_exists( 'serifi_paging_nav' ) ) :
function serifi_paging_nav() {
			the_posts_pagination( array(
				'prev_text'          => is_rtl() ? '<i class="bi bi-chevron-double-right"></i>' : '<i class="bi bi-chevron-double-left"></i>',
				'next_text'          =>  is_rtl() ? '<i class="bi bi-chevron-double-left"></i>' : '<i class="bi bi-chevron-double-right"></i>',
				'before_page_number' => ''
			) );	
}
endif;


/* POST NAVIGATION
	Navigation for full posts.
   ==================================================== */
if ( ! function_exists( 'serifi_post_pagination' ) ) :
	function serifi_post_pagination() {
	
        the_post_navigation( array(
          'next_text' => '<span class="nav-meta">' . ( is_singular( 'post' ) ? esc_html__( 'Next post', 'serifi' ) : esc_html__( 'Next', 'serifi' ) ) . '</span> <span class="post-title">%title</span>',
          'prev_text' => '<span class="nav-meta">' . ( is_singular( 'post' ) ? esc_html__( 'Previous post', 'serifi' ) : esc_html__( 'Previous', 'serifi' ) ) . '</span> <span class="post-title">%title</span>',
        ) ); 
		
	}
endif;


/* MULTIPAGE NAVIGATION
	Navigation for splitting posts or pages into more than one page.
   ==================================================== */	
if ( ! function_exists( 'serifi_multipage_pagination' ) ) :
	function serifi_multipage_pagination() {
	
		wp_link_pages( array(
			'before'      => '<div class="multi-page-links"><span class="multi-page-links-title">' . esc_html__( 'Pages:', 'serifi' ) . '</span>',
			'after'       => '</div>',
			'link_before' => '<span>',
			'link_after'  => '</span>',
			'pagelink'    => ' %',
			'separator'   => ', ',
		) );
	}
endif;